﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using LogicModule.Nodes.TestHelper;
using LogicModule.ObjectModel;
using LogicNodesSDK.Logic.Examples;
using NUnit.Framework;

namespace ExampleNodesTest
{
  [TestFixture]
  class TimedAverageTest
  {
    private INodeContext context;
    private TimedAverage node;
    private MockSchedulerService schedulerService;

    public TimedAverageTest()
    {
      context = TestNodeContext.Create();
      schedulerService = (MockSchedulerService) context.GetService<ISchedulerService>();
    }

    [SetUp]
    public void TimedAverageTestSetUp()
    {
      node = new TimedAverage(context);
    }

    [TearDown]
    public void TimedAverageTestTearDown()
    {
      node = null;
    }

    [Test]
    public void AveragingValuesTest()
    {
      node.AverageTime.Value = new TimeSpan(0, 0, 6);
      node.UpdateAutomatically.Value = true;

      node.Input.Value = 5;
      node.Execute();
      Assert.AreEqual(5, node.Output.Value);

      schedulerService.Tick(3);
      
      node.Input.Value = 10;
      node.Execute();
      Assert.AreEqual(7.5, node.Output.Value);
      
      node.Input.Value = 15;
      node.Execute();
      Assert.AreEqual(10, node.Output.Value);

      schedulerService.Tick(4);

      Assert.AreEqual(12.5, node.Output.Value);
    }

    [Test]
    public void ResetNodeTest()
    {
      node.Input.Value = 10;
      node.Execute();
      Assert.AreEqual(10, node.Output.Value);

      node.Reset.Value = true;
      node.Input.Value = 3;
      node.Execute();
      Assert.AreEqual(3, node.Output.Value);
    }
  }
}
